@@ -31,7 +31,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 348362 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 356042 $")
 
 #include "asterisk/lock.h"
 #include "asterisk/file.h"
@@ -133,7 +133,7 @@ static int auth_exec(struct ast_channel *chan, const char *data)
 		return -1;
 	}
 
-	if (chan->_state != AST_STATE_UP) {
+	if (ast_channel_state(chan) != AST_STATE_UP) {
 		if ((res = ast_answer(chan)))
 			return -1;
 	}
@@ -253,10 +253,10 @@ static int auth_exec(struct ast_channel *chan, const char *data)
 			ast_cdr_setaccount(chan, passwd);
 			ast_channel_unlock(chan);
 		}
-		if (!(res = ast_streamfile(chan, "auth-thankyou", chan->language)))
+		if (!(res = ast_streamfile(chan, "auth-thankyou", ast_channel_language(chan))))
 			res = ast_waitstream(chan, "");
 	} else {
-		if (!ast_streamfile(chan, "vm-goodbye", chan->language))
+		if (!ast_streamfile(chan, "vm-goodbye", ast_channel_language(chan)))
 			res = ast_waitstream(chan, "");
 		res = -1;
 	}
