@@ -29,7 +29,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 411314 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 413587 $")
 #include "asterisk/logger.h"
 #include "asterisk/config.h"
 #include "asterisk/config_options.h"
@@ -476,7 +476,7 @@ static int add_action_to_menu_entry(struct conf_menu_entry *menu_entry, enum con
 			}
 			menu_action->data.dialplan_args.priority = 1; /* 1 by default */
 			if (!ast_strlen_zero(args.priority) &&
-				(sscanf(args.priority, "%30u", &menu_action->data.dialplan_args.priority) != 1)) {
+				(sscanf(args.priority, "%30d", &menu_action->data.dialplan_args.priority) != 1)) {
 				/* invalid priority */
 				ast_free(menu_action);
 				return -1;
@@ -743,9 +743,9 @@ static char *handle_cli_confbridge_show_user_profile(struct ast_cli_entry *e, in
 	ast_cli(a->fd,"Drop_silence:            %s\n",
 		u_profile.flags & USER_OPT_DROP_SILENCE ?
 		"enabled" : "disabled");
-	ast_cli(a->fd,"Silence Threshold:       %dms\n",
+	ast_cli(a->fd,"Silence Threshold:       %ums\n",
 		u_profile.silence_threshold);
-	ast_cli(a->fd,"Talking Threshold:       %dms\n",
+	ast_cli(a->fd,"Talking Threshold:       %ums\n",
 		u_profile.talking_threshold);
 	ast_cli(a->fd,"Denoise:                 %s\n",
 		u_profile.flags & USER_OPT_DENOISE ?
@@ -868,14 +868,14 @@ static char *handle_cli_confbridge_show_bridge_profile(struct ast_cli_entry *e,
 	ast_cli(a->fd,"Language:             %s\n", b_profile.language);
 
 	if (b_profile.internal_sample_rate) {
-		snprintf(tmp, sizeof(tmp), "%d", b_profile.internal_sample_rate);
+		snprintf(tmp, sizeof(tmp), "%u", b_profile.internal_sample_rate);
 	} else {
 		ast_copy_string(tmp, "auto", sizeof(tmp));
 	}
 	ast_cli(a->fd,"Internal Sample Rate: %s\n", tmp);
 
 	if (b_profile.mix_interval) {
-		ast_cli(a->fd,"Mixing Interval:      %d\n", b_profile.mix_interval);
+		ast_cli(a->fd,"Mixing Interval:      %u\n", b_profile.mix_interval);
 	} else {
 		ast_cli(a->fd,"Mixing Interval:      Default 20ms\n");
 	}
@@ -889,7 +889,7 @@ static char *handle_cli_confbridge_show_bridge_profile(struct ast_cli_entry *e,
 		b_profile.rec_file);
 
 	if (b_profile.max_members) {
-		ast_cli(a->fd,"Max Members:          %d\n", b_profile.max_members);
+		ast_cli(a->fd,"Max Members:          %u\n", b_profile.max_members);
 	} else {
 		ast_cli(a->fd,"Max Members:          No Limit\n");
 	}
@@ -1366,7 +1366,7 @@ int conf_load_config(void)
 	aco_option_register(&cfg_info, "denoise", ACO_EXACT, user_types, "no", OPT_BOOLFLAG_T, 1, FLDSET(struct user_profile, flags), USER_OPT_DENOISE);
 	aco_option_register(&cfg_info, "dsp_drop_silence", ACO_EXACT, user_types, "no", OPT_BOOLFLAG_T, 1, FLDSET(struct user_profile, flags), USER_OPT_DROP_SILENCE);
 	aco_option_register(&cfg_info, "dsp_silence_threshold", ACO_EXACT, user_types, __stringify(DEFAULT_SILENCE_THRESHOLD), OPT_UINT_T, 0, FLDSET(struct user_profile, silence_threshold));
-	aco_option_register(&cfg_info, "dsp_talking_threshold", ACO_EXACT, user_types, __stringify(DEFAULT_TALKING_THRESHOLD), OPT_UINT_T, 0, FLDSET(struct user_profile, silence_threshold));
+	aco_option_register(&cfg_info, "dsp_talking_threshold", ACO_EXACT, user_types, __stringify(DEFAULT_TALKING_THRESHOLD), OPT_UINT_T, 0, FLDSET(struct user_profile, talking_threshold));
 	aco_option_register(&cfg_info, "jitterbuffer", ACO_EXACT, user_types, "no", OPT_BOOLFLAG_T, 1, FLDSET(struct user_profile, flags), USER_OPT_JITTERBUFFER);
 	/* This option should only be used with the CONFBRIDGE dialplan function */
 	aco_option_register_custom(&cfg_info, "template", ACO_EXACT, user_types, NULL, user_template_handler, 0);
