@@ -41,7 +41,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 355321 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 416337 $")
 
 #include <sqlite3.h>
 
@@ -231,7 +231,6 @@ static void write_cel(const struct ast_event *event, void *userdata)
 {
 	char *error = NULL;
 	char *sql = NULL;
-	int count = 0;
 
 	if (db == NULL) {
 		/* Should not have loaded, but be failsafe. */
@@ -266,18 +265,7 @@ static void write_cel(const struct ast_event *event, void *userdata)
 		ast_free(value_string);
 	}
 
-	/* XXX This seems awful arbitrary... */
-	for (count = 0; count < 5; count++) {
-		int res = sqlite3_exec(db, sql, NULL, NULL, &error);
-		if (res != SQLITE_BUSY && res != SQLITE_LOCKED) {
-			break;
-		}
-		usleep(200);
-	}
-
-	ast_mutex_unlock(&lock);
-
-	if (error) {
+	if (sqlite3_exec(db, sql, NULL, NULL, &error) != SQLITE_OK) {
 		ast_log(LOG_ERROR, "%s. SQL: %s.\n", error, sql);
 		sqlite3_free(error);
 	}
@@ -285,6 +273,7 @@ static void write_cel(const struct ast_event *event, void *userdata)
 	if (sql) {
 		sqlite3_free(sql);
 	}
+	ast_mutex_unlock(&lock);
 
 	return;
 }
@@ -319,7 +308,7 @@ static int load_module(void)
 		free_config();
 		return AST_MODULE_LOAD_DECLINE;
 	}
-
+	sqlite3_busy_timeout(db, 1000);
 	/* is the table there? */
 	sql = sqlite3_mprintf("SELECT COUNT(*) FROM %q;", table);
 	res = sqlite3_exec(db, sql, NULL, NULL, NULL);
