@@ -29,7 +29,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 398305 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 413587 $")
 
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -97,7 +97,7 @@ static void dump_string_hex(char *output, int maxlen, void *value, int len)
 	int i = 0;
 
 	while (len-- && (i + 1) * 4 < maxlen) {
-		sprintf(output + (4 * i), "\\x%2.2x", *((unsigned char *)value + i));
+		sprintf(output + (4 * i), "\\x%2.2x", (unsigned)*((unsigned char *)value + i));
 		i++;
 	}
 }
@@ -1123,7 +1123,7 @@ int iax_parse_ies(struct iax_ies *ies, unsigned char *data, int datalen)
 				ies->osptokenblock[count] = (char *)data + 2 + 1;
 				ies->ospblocklength[count] = len - 1;
 			} else {
-				snprintf(tmp, (int)sizeof(tmp), "Expected OSP token block index to be 0~%d but was %d\n", IAX_MAX_OSPBLOCK_NUM - 1, count);
+				snprintf(tmp, (int)sizeof(tmp), "Expected OSP token block index to be 0~%d but was %u\n", IAX_MAX_OSPBLOCK_NUM - 1, count);
 				errorf(tmp);
 			}
 			break;
