@@ -30,7 +30,7 @@
  
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 364580 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 413587 $")
 
 #include "asterisk/mod_format.h"
 #include "asterisk/module.h"
@@ -304,24 +304,24 @@ static int check_header(FILE *f)
 /*	data_size = ltohl(header[AU_HDR_DATA_SIZE_OFF]); */
 	encoding = ltohl(header[AU_HDR_ENCODING_OFF]);
 	if (encoding != AU_ENC_8BIT_ULAW) {
-		ast_log(LOG_WARNING, "Unexpected format: %d. Only 8bit ULAW allowed (%d)\n", encoding, AU_ENC_8BIT_ULAW);
+		ast_log(LOG_WARNING, "Unexpected format: %u. Only 8bit ULAW allowed (%d)\n", encoding, AU_ENC_8BIT_ULAW);
 		return -1;
 	}
 	sample_rate = ltohl(header[AU_HDR_SAMPLE_RATE_OFF]);
 	if (sample_rate != DEFAULT_SAMPLE_RATE) {
-		ast_log(LOG_WARNING, "Sample rate can only be 8000 not %d\n", sample_rate);
+		ast_log(LOG_WARNING, "Sample rate can only be 8000 not %u\n", sample_rate);
 		return -1;
 	}
 	channels = ltohl(header[AU_HDR_CHANNELS_OFF]);
 	if (channels != 1) {
-		ast_log(LOG_WARNING, "Not in mono: channels=%d\n", channels);
+		ast_log(LOG_WARNING, "Not in mono: channels=%u\n", channels);
 		return -1;
 	}
 	/* Skip to data */
 	fseek(f, 0, SEEK_END);
 	data_size = ftell(f) - hdr_size;
 	if (fseek(f, hdr_size, SEEK_SET) == -1 ) {
-		ast_log(LOG_WARNING, "Failed to skip to data: %d\n", hdr_size);
+		ast_log(LOG_WARNING, "Failed to skip to data: %u\n", hdr_size);
 		return -1;
 	}
 	return data_size;
