@@ -30,7 +30,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 389896 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 413587 $")
 
 #include "asterisk/frame.h"
 #include "asterisk/slinfactory.h"
@@ -91,7 +91,7 @@ int ast_slinfactory_feed(struct ast_slinfactory *sf, struct ast_frame *f)
 
 		if (!sf->trans) {
 			if (!(sf->trans = ast_translator_build_path(&sf->output_format, &f->subclass.format))) {
-				ast_log(LOG_WARNING, "Cannot build a path from %s (%d)to %s (%d)\n",
+				ast_log(LOG_WARNING, "Cannot build a path from %s (%u)to %s (%u)\n",
 					ast_getformatname(&f->subclass.format),
 					f->subclass.format.id,
 					ast_getformatname(&sf->output_format),
