@@ -36,7 +36,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 369323 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 369326 $")
 
 #include <time.h>
 #include <math.h>
@@ -100,7 +100,7 @@ static int adsi_set_keys(unsigned char *buf, unsigned char *keys);
 static int adsi_input_control(unsigned char *buf, int page, int line, int display, int format, int just);
 static int adsi_input_format(unsigned char *buf, int num, int dir, int wrap, char *format1, char *format2);
 
-static int adsi_generate(unsigned char *buf, int msgtype, unsigned char *msg, int msglen, int msgnum, int last, format_t codec)
+static int adsi_generate(unsigned char *buf, int msgtype, unsigned char *msg, int msglen, int msgnum, int last, struct ast_format *codec)
 {
 	int sum, x, bytes = 0;
 	/* Initial carrier (imaginary) */
@@ -170,7 +170,7 @@ static int adsi_careful_send(struct ast_channel *chan, unsigned char *buf, int l
 			*remain = *remain - amt;
 		}
 		outf.frametype = AST_FRAME_VOICE;
-		outf.subclass.codec = AST_FORMAT_ULAW;
+		ast_format_set(&outf.subclass.format, AST_FORMAT_ULAW, 0);
 		outf.data.ptr = buf;
 		outf.datalen = amt;
 		outf.samples = amt;
@@ -201,7 +201,7 @@ static int adsi_careful_send(struct ast_channel *chan, unsigned char *buf, int l
 			continue;
 		}
 
-		if (inf->subclass.codec != AST_FORMAT_ULAW) {
+		if (inf->subclass.format.id != AST_FORMAT_ULAW) {
 			ast_log(LOG_WARNING, "Channel not in ulaw?\n");
 			ast_frfree(inf);
 			return -1;
@@ -213,7 +213,7 @@ static int adsi_careful_send(struct ast_channel *chan, unsigned char *buf, int l
 			*remain = inf->datalen - amt;
 		}
 		outf.frametype = AST_FRAME_VOICE;
-		outf.subclass.codec = AST_FORMAT_ULAW;
+		ast_format_set(&outf.subclass.format, AST_FORMAT_ULAW, 0);
 		outf.data.ptr = buf;
 		outf.datalen = amt;
 		outf.samples = amt;
@@ -238,16 +238,18 @@ static int __adsi_transmit_messages(struct ast_channel *chan, unsigned char **ms
 	char ack[3];
 	struct ast_frame *f;
 
-	if (chan->adsicpe == AST_ADSI_UNAVAILABLE) {
+	if (ast_channel_adsicpe(chan) == AST_ADSI_UNAVAILABLE) {
 		/* Don't bother if we know they don't support ADSI */
 		errno = ENOSYS;
 		return -1;
 	}
 
 	while (retries < maxretries) {
-		if (!(chan->adsicpe & ADSI_FLAG_DATAMODE)) {
+		struct ast_format tmpfmt;
+		if (!(ast_channel_adsicpe(chan) & ADSI_FLAG_DATAMODE)) {
 			/* Generate CAS (no SAS) */
-			ast_gen_cas(buf, 0, 680, AST_FORMAT_ULAW);
+			ast_format_set(&tmpfmt, AST_FORMAT_ULAW, 0);
+			ast_gen_cas(buf, 0, 680, &tmpfmt);
 
 			/* Send CAS */
 			if (adsi_careful_send(chan, buf, 680, NULL)) {
@@ -260,8 +262,8 @@ static int __adsi_transmit_messages(struct ast_channel *chan, unsigned char **ms
 				if (((res = ast_waitfor(chan, waittime)) < 1)) {
 					/* Didn't get back DTMF A in time */
 					ast_debug(1, "No ADSI CPE detected (%d)\n", res);
-					if (!chan->adsicpe) {
-						chan->adsicpe = AST_ADSI_UNAVAILABLE;
+					if (!ast_channel_adsicpe(chan)) {
+						ast_channel_adsicpe_set(chan, AST_ADSI_UNAVAILABLE);
 					}
 					errno = ENOSYS;
 					return -1;
@@ -274,8 +276,8 @@ static int __adsi_transmit_messages(struct ast_channel *chan, unsigned char **ms
 				if (f->frametype == AST_FRAME_DTMF) {
 					if (f->subclass.integer == 'A') {
 						/* Okay, this is an ADSI CPE.  Note this for future reference, too */
-						if (!chan->adsicpe) {
-							chan->adsicpe = AST_ADSI_AVAILABLE;
+						if (!ast_channel_adsicpe(chan)) {
+							ast_channel_adsicpe_set(chan, AST_ADSI_AVAILABLE);
 						}
 						break;
 					} else {
@@ -284,8 +286,8 @@ static int __adsi_transmit_messages(struct ast_channel *chan, unsigned char **ms
 						} else {
 							ast_log(LOG_WARNING, "Unknown ADSI response '%c'\n", f->subclass.integer);
 						}
-						if (!chan->adsicpe) {
-							chan->adsicpe = AST_ADSI_UNAVAILABLE;
+						if (!ast_channel_adsicpe(chan)) {
+							ast_channel_adsicpe_set(chan, AST_ADSI_UNAVAILABLE);
 						}
 						errno =	ENOSYS;
 						ast_frfree(f);
@@ -306,8 +308,8 @@ static int __adsi_transmit_messages(struct ast_channel *chan, unsigned char **ms
 		def= ast_channel_defer_dtmf(chan);
 #endif
 		while ((x < 6) && msg[x]) {
-			if ((res = adsi_generate(buf + pos, msgtype[x], msg[x], msglen[x], x+1 - start, (x == 5) || !msg[x+1], AST_FORMAT_ULAW)) < 0) {
-				ast_log(LOG_WARNING, "Failed to generate ADSI message %d on channel %s\n", x + 1, chan->name);
+			if ((res = adsi_generate(buf + pos, msgtype[x], msg[x], msglen[x], x+1 - start, (x == 5) || !msg[x+1], ast_format_set(&tmpfmt, AST_FORMAT_ULAW,0))) < 0) {
+				ast_log(LOG_WARNING, "Failed to generate ADSI message %d on channel %s\n", x + 1, ast_channel_name(chan));
 				return -1;
 			}
 			ast_debug(1, "Message %d, of %d input bytes, %d output bytes\n", x + 1, msglen[x], res);
@@ -392,7 +394,12 @@ static int adsi_end_download(struct ast_channel *chan)
 static int adsi_transmit_message_full(struct ast_channel *chan, unsigned char *msg, int msglen, int msgtype, int dowait)
 {
 	unsigned char *msgs[5] = { NULL, NULL, NULL, NULL, NULL };
-	int msglens[5], msgtypes[5], newdatamode = (chan->adsicpe & ADSI_FLAG_DATAMODE), res, x, writeformat = chan->writeformat, readformat = chan->readformat, waitforswitch = 0;
+	int msglens[5], msgtypes[5], newdatamode = (ast_channel_adsicpe(chan) & ADSI_FLAG_DATAMODE), res, x, waitforswitch = 0;
+	struct ast_format writeformat;
+	struct ast_format readformat;
+
+	ast_format_copy(&writeformat, ast_channel_writeformat(chan));
+	ast_format_copy(&readformat, ast_channel_readformat(chan));
 
 	for (x = 0; x < msglen; x += (msg[x+1]+2)) {
 		if (msg[x] == ADSI_SWITCH_TO_DATA) {
@@ -419,16 +426,16 @@ static int adsi_transmit_message_full(struct ast_channel *chan, unsigned char *m
 
 	ast_stopstream(chan);
 
-	if (ast_set_write_format(chan, AST_FORMAT_ULAW)) {
+	if (ast_set_write_format_by_id(chan, AST_FORMAT_ULAW)) {
 		ast_log(LOG_WARNING, "Unable to set write format to ULAW\n");
 		return -1;
 	}
 
-	if (ast_set_read_format(chan, AST_FORMAT_ULAW)) {
+	if (ast_set_read_format_by_id(chan, AST_FORMAT_ULAW)) {
 		ast_log(LOG_WARNING, "Unable to set read format to ULAW\n");
-		if (writeformat) {
-			if (ast_set_write_format(chan, writeformat)) {
-				ast_log(LOG_WARNING, "Unable to restore write format to %d\n", writeformat);
+		if (writeformat.id) {
+			if (ast_set_write_format(chan, &writeformat)) {
+				ast_log(LOG_WARNING, "Unable to restore write format to %s\n", ast_getformatname(&writeformat));
 			}
 		}
 		return -1;
@@ -444,14 +451,14 @@ static int adsi_transmit_message_full(struct ast_channel *chan, unsigned char *m
 	}
 
 	if (!res) {
-		chan->adsicpe = (chan->adsicpe & ~ADSI_FLAG_DATAMODE) | newdatamode;
+		ast_channel_adsicpe_set(chan, (ast_channel_adsicpe(chan) & ~ADSI_FLAG_DATAMODE) | newdatamode);
 	}
 
-	if (writeformat) {
-		ast_set_write_format(chan, writeformat);
+	if (writeformat.id) {
+		ast_set_write_format(chan, &writeformat);
 	}
-	if (readformat) {
-		ast_set_read_format(chan, readformat);
+	if (readformat.id) {
+		ast_set_read_format(chan, &readformat);
 	}
 
 	if (!res) {
@@ -807,7 +814,7 @@ static int adsi_voice_mode(unsigned char *buf, int when)
 
 static int adsi_available(struct ast_channel *chan)
 {
-	int cpe = chan->adsicpe & 0xff;
+	int cpe = ast_channel_adsicpe(chan) & 0xff;
 	if ((cpe == AST_ADSI_AVAILABLE) ||
 	    (cpe == AST_ADSI_UNKNOWN)) {
 		return 1;
