@@ -36,7 +36,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 370387 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 419162 $")
 
 #include "asterisk/utils.h"
 #include "asterisk/module.h"
@@ -116,6 +116,15 @@ static struct ast_frame *create_test_frame(long timestamp,
 		return AST_TEST_FAIL; \
 	} } while (0)
 
+/*! \internal
+ * \brief Test two numeric (unsigned int) values.
+*/
+#define UINT_TEST(actual, expected) do { \
+	if ((actual) != (expected)) { \
+		ast_test_status_update(test, #actual ": expected [%u]; actual [%u]\n", (expected), (actual)); \
+		return AST_TEST_FAIL; \
+	} } while (0)
+
 /*! \internal
  * \brief Test two string values
 */
@@ -129,7 +138,7 @@ static struct ast_frame *create_test_frame(long timestamp,
  * \brief Verify that two frames have the same properties
  */
 #define VERIFY_FRAME(actual, expected) do { \
-	INT_TEST((actual)->frametype, (expected)->frametype); \
+	UINT_TEST((actual)->frametype, (expected)->frametype); \
 	INT_TEST((actual)->seqno, (expected)->seqno); \
 	LONG_INT_TEST((actual)->ts, (expected)->ts); \
 	LONG_INT_TEST((actual)->len, (expected)->len); \
